@echo off

::
:: This script installs uberAgent silently
::
:: This script can be used to install uberAgent through Splunk's Deployment server
:: Alternatively you can simply install the MSI through other means
:: 
:: Requirements:
::
:: - The following files must be present in the same directory as this batch file
::    - uberAgent-en-32.msi (or other languages)
::    - uberAgent-en-64.msi (or other languages)
::
::   To install a localized version of uberAgent, modify the MSILanguage variable.
::
:: Return values:
::
::    1  ->    Required file is missing
::    x  ->    Return value from msiexec
::

:::::::::::::::::::::::::::::::::::::::::
::
:: Variables - DO edit
::
:::::::::::::::::::::::::::::::::::::::::

set MSILanguage=en

::
:: Set the following variable to 1, if you want to register uberAgent's Internet Explorer add-on automatically
::
set RegisterIEAddOn=0

:::::::::::::::::::::::::::::::::::::::::
::
:: Start of script
::
:::::::::::::::::::::::::::::::::::::::::

::
:: Select 32- or 64-bit version according to the bitness of the OS
::
if defined programfiles(x86) (
   set installer=%~dp0uberAgent-%MSILanguage%-64.msi
) else (
   set installer=%~dp0uberAgent-%MSILanguage%-32.msi
)

:: Check prerequisites
if not exist "%installer%" (
   echo ERROR uberAgent MSI not found. Filename: %installer% >&2
	exit /b 1
)

::
:: Copy license file and custom configuration files
::
if not exist "%ProgramData%\vast limits" (
   mkdir "%ProgramData%\vast limits"
   icacls "%ProgramData%\vast limits" /inheritance:r /grant:r "*S-1-5-32-544:(OI)(CI)F" /grant:r "*S-1-5-18:(OI)(CI)F"
)   

if exist "%~dp0uberAgent*.lic" (
   xcopy "%~dp0uberAgent*.lic" "%ProgramData%\vast limits\uberAgent\License cache\" /y /s /v /e
)

if exist "%~dp0uberAgent*.conf" (
   if exist "%ProgramData%\vast limits\uberAgent\Configuration\" (
      rmdir /S /Q "%ProgramData%\vast limits\uberAgent\Configuration\"
      mkdir "%ProgramData%\vast limits\uberAgent\Configuration\"
   )
   set msiParamString=%msiParamString% PROGRAMDATA_CONFIGDIR_DELETEFILES=0
   xcopy "%~dp0uberAgent*.conf" "%ProgramData%\vast limits\uberAgent\Configuration\" /y /s /v /e
)

if exist "%~dp0Security Inventory\" (
   if exist "%ProgramData%\vast limits\uberAgent\Security Inventory\" (
      rmdir /S /Q "%ProgramData%\vast limits\uberAgent\Security Inventory\"
   )

   mkdir "%ProgramData%\vast limits\uberAgent\Security Inventory\"
   xcopy "%~dp0Security Inventory" "%ProgramData%\vast limits\uberAgent\Security Inventory\" /y /s /v /e
)

::
:: Run the installer
::
echo INFO Running the installer... >&2

start /wait msiexec /i "%installer%" /quiet /l*v "%temp%\uberAgentMsi.log" %msiParamString% 1>nul

::
:: Register IE browser helper objects (BHO)
::
if "%RegisterIEAddOn%" == "1" (
   if exist "%ProgramFiles%\vast limits\uberAgent\uAIEExtension32.dll" (
      regsvr32 /s "%ProgramFiles%\vast limits\uberAgent\uAIEExtension32.dll"
   )
   if exist "%ProgramFiles%\vast limits\uberAgent\uAIEExtension64.dll" (
      regsvr32 /s "%ProgramFiles%\vast limits\uberAgent\uAIEExtension64.dll"
   )
)

echo INFO ...done! >&2

exit /b %errorlevel%