require([
   'jquery',
   'splunkjs/mvc/tableview',
   'splunkjs/mvc',
   'underscore',
   'splunkjs/mvc/simplexml/ready!'
],function(
   $,
   TableView,
   mvc,
   _
)
{
   // Functions
   function UnsetToken(name) {
      var defaultTokenModel = mvc.Components.getInstance('default', {create: true});
      var submittedTokenModel = mvc.Components.getInstance('submitted', {create: true});

      defaultTokenModel.unset(name);
      submittedTokenModel.unset(name);
   }

   // Set tokens depending on mode
   var mode = GetToken (mvc, "mode");
   var regex = /[^|]+/;
   var easySplunkVersion = GetEasySplunkVersion (mvc);

   if (mode == "WindowsServices")
   {
      // Service dashboard
      
      // Page title and description
      document.title = document.title.replace (regex, gettext("Windows Services "));
      if (easySplunkVersion >= 70300)
      {
         $('.dashboard-header > h1').text (gettext("Windows Services "));
      }
      else
      {
         $('.dashboard-header > h2').text (gettext("Windows Services "));
      }
      $('.dashboard-header > p.description').text (gettext("This dashboard displays detailed information about Windows services."));  

      SetToken (mvc, "TagFilter", gettext("Tag filter:"));
      SetToken (mvc, "AMETagFilter", "reg-key-create-service");

      SetToken (mvc, "Heading_Single", gettext("Windows service"));

      SetToken (mvc, "SecurityInventoryCategoryFilter", "Service");

      SetToken (mvc, "AMEGroupByFieldName", "GenericProperty2Data");
      SetToken (mvc, "AMEGroupByFieldDisplayName", "Service");
      SetToken (mvc, "AMEGroupByFieldDisplayNamePlural", "Services");
   }
   else if (mode == "RootCerts")
   {
      // Certificate dashboard
      // Page title and description
      document.title = document.title.replace (regex, gettext("Root Certificates "));
      if (easySplunkVersion >= 70300)
      {
         $('.dashboard-header > h1').text (gettext("Root Certificates "));
      }
      else
      {
         $('.dashboard-header > h2').text (gettext("Root Certificates "));
      }
      $('.dashboard-header > p.description').text (gettext("This dashboard displays detailed information about new root certificates."));
      
      SetToken (mvc, "TagFilter", gettext("Tag filter:"));
      SetToken (mvc, "AMETagFilter", "reg-value-write-cert-change");

      SetToken (mvc, "Heading_Single", gettext("Certificate"));

      SetToken (mvc, "SecurityInventoryCategoryFilter", "Certificate");

      SetToken (mvc, "AMEGroupByFieldName", "GenericProperty2Data");
      SetToken (mvc, "AMEGroupByFieldDisplayName", "Thumbprint");
      SetToken (mvc, "AMEGroupByFieldDisplayNamePlural", "Thumbprints");
   }
   else
   {
      return;
   }

   // Format commandline column
   var TimebarCellRenderer = TableView.BaseCellRenderer.extend(
      {
         // Called to check whether to invoke our custom renderer
         canRender: function(cell)
         {
            return (cell.field === 'Command line' || cell.field === 'Path' );
         },
         
         // The render function is only called when canRender returns true
         render: function($td, cell)
         {
            if (cell.value === null)
            {
               return;
            }
   
            if (cell.field === 'Command line')
            {
               var message = cell.value;
               var tooltip = cell.value;
               
               message = message.replace ("\\SystemRoot\\System32\\", "...\\");
               message = message.replace ("%SystemRoot%\\system32\\", "...\\");
               message = message.replace ("\\??\\C:\\Windows\\system32\\", "...\\");
               message = message.replace ("C:\\Windows\\system32\\", "...\\");
               message = message.replace ("C:\\Program Files (x86)\\", "...\\");
               message = message.replace ("C:\\Program Files\\", "...\\");
               message = message.replace ("C:\\Windows\\SysWOW64\\", "...\\");
               message = message.replace ("C:\\Windows\\", "...\\");
               if (message.length > 50)
               {
                  message = message.substring(0, 49) + "...";
               }
                  
               $td.html(_.template('<div title="<%- tooltip %>"> <%- text %></div>',
               {
                  text:       message,
                  tooltip:    tooltip
               }));
            }
   
         }
      });

   mvc.Components.get('Table_Panel41').getVisualization(function(tableView)
   {
      // Register custom cell renderer
      tableView.table.addCellRenderer(new TimebarCellRenderer());
      
      // Force the table to re-render
      tableView.table.render();
   });

   // Custom drilldowns
   var TablePanel41 = mvc.Components.getInstance ("Table_Panel41");
   TablePanel41.on ("click:row", drilldown41);

   function drilldown41 (event)
   {
      // Don't do any further event processing
      event.preventDefault ();
      
      if (event.data["click.name2"] == "ATT&CK techniques")
      {
         var DrilldownFilterBy41 = event.data["click.value2"];         
         if (DrilldownFilterBy41 != null)
         {
            SetToken (mvc, "ShowPanel42", true, submit);
            SetToken (mvc, "DrilldownFilterBy41", DrilldownFilterBy41, submit);
         }
      }
      else
      {
         var earliest = GetToken (mvc, "earliest");
         var latest = GetToken (mvc, "latest");
         
         var drilldownUrl = "process_tree";
         drilldownUrl += "?earliest=" + encodeURIComponent (earliest);
         drilldownUrl += "&latest=" + encodeURIComponent (latest);
         drilldownUrl += "&form.HostFilter=" + encodeURIComponent ((event.data["row.Host"]));
         drilldownUrl += "&form.Panel41ProcessNameFilter=" + encodeURIComponent ((event.data["row.ProcName"]));

         window.open(drilldownUrl);
      }

   }

   // Attach click event handlers to dashboard controls
   $(document).on("click", "#Panel42CloseBtn", function() {
      UnsetToken("ShowPanel42");
      UnsetToken("DrilldownFilterBy41");
      UnsetToken("MitreName");
      UnsetToken("MitreID");
      UnsetToken("MitreURL");
      UnsetToken("MitreDesc");
      UnsetToken("MitreDet");
  });


  var submittedTokens = mvc.Components.get('submitted');
   // Listen for a change to the token MitreDesc value
   submittedTokens.on("change:MitreDesc", function(model, MitreDesc, options) {
      var MitreDescJS=submittedTokens.get("MitreDesc");
      if (MitreDescJS!==undefined)
      {
         $("#Panel42MitreDesc").html(MitreDescJS);
      }
   });

   // Listen for a change to the token MitreDet value
   submittedTokens.on("change:MitreDet", function(model, MitreDet, options) {
      var MitreDetJS=submittedTokens.get("MitreDet");
      if (MitreDetJS!==undefined)
      {
         $("#Panel42MitreDet").html(MitreDetJS);
      }
   });

   //
   // Submit the changed tokens
   //
   SubmitTokens (mvc);
});